@@ -20,94 +20,30 @@ import string
 import sys
 
 import dragonlib
-from basic_editor.editor_base import BaseExtension
-from basic_editor.highlighting import TkTextHighlighting
+from basic_editor.scrolled_text import ScrolledText
+from basic_editor.status_bar import MultiStatusBar
+from basic_editor.token_window import TokenWindow
+from basic_editor.highlighting import TkTextHighlighting, TkTextHighlightCurrentLine
 from dragonlib.utils.auto_shift import invert_shift
-from dragonlib.utils.logging_utils import pformat_program_dump
+
 
 log = logging.getLogger(__name__)
 
-
 try:
     # Python 3
     import tkinter
     from tkinter import filedialog
     from tkinter import messagebox
-    from tkinter import scrolledtext
 except ImportError:
     # Python 2
     import Tkinter as tkinter
     import tkFileDialog as filedialog
     import tkMessageBox as messagebox
-    import ScrolledText as scrolledtext
 
 
-class MultiStatusBar(tkinter.Frame):
-    """
-    code from idlelib.MultiStatusBar.MultiStatusBar
-    """
-    def __init__(self, master, **kw):
-        tkinter.Frame.__init__(self, master, **kw)
-        self.labels = {}
-
-    def set_label(self, name, text='', side=tkinter.LEFT):
-        if name not in self.labels:
-            label = tkinter.Label(self, bd=1, relief=tkinter.SUNKEN, anchor=tkinter.W)
-            label.pack(side=side)
-            self.labels[name] = label
-        else:
-            label = self.labels[name]
-        label.config(text=text)
-
-
-class TkTextHighlightCurrentLine(BaseExtension):
-    after_id = None
-    TAG_CURRENT_LINE = "current_line"
-    def __init__(self, editor):
-        super(TkTextHighlightCurrentLine, self).__init__(editor)
-
-        self.text.tag_config(self.TAG_CURRENT_LINE, background="#e8f2fe")
-
-        self.current_line = None
-        self.__update_interval()
-
-    def update(self, force=False):
-        """ highlight the current line """
-        line_no = self.text.index(tkinter.INSERT).split('.')[0]
-
-        if not force:
-            if line_no == self.current_line:
-#                 log.critical("no highlight line needed.")
-                return
-
-#         log.critical("highlight line: %s" % line_no)
-        self.current_line = line_no
-
-        self.text.tag_remove(self.TAG_CURRENT_LINE, "1.0", "end")
-        self.text.tag_add(self.TAG_CURRENT_LINE, "%s.0" % line_no, "%s.0+1lines" % line_no)
-
-    def __update_interval(self):
-        """ highlight the current line """
-        self.update()
-        self.after_id = self.text.after(10, self.__update_interval)
-
-
-class ScrolledText2(scrolledtext.ScrolledText):
-    def save_position(self):
-        # save text cursor position:
-        self.old_text_pos = self.index(tkinter.INSERT)
-        # save scroll position:
-        self.old_first, self.old_last = self.yview()
-
-    def restore_position(self):
-        # restore text cursor position:
-        self.mark_set(tkinter.INSERT, self.old_text_pos)
-        # restore scroll position:
-        self.yview_moveto(self.old_first)
-
 
 class EditorWindow(object):
-    FILETYPES = [ # For filedialog
+    FILETYPES = [# For filedialog
         ("BASIC Listings", "*.bas", "TEXT"),
         ("Text files", "*.txt", "TEXT"),
         ("All files", "*"),
@@ -142,7 +78,7 @@ class EditorWindow(object):
         self.base_title = "%s - BASIC Editor" % self.cfg.MACHINE_NAME
         self.root.title(self.base_title)
 
-        self.text = ScrolledText2(
+        self.text = ScrolledText(
             master=self.root, height=30, width=80
         )
         self.text.config(
@@ -168,6 +104,7 @@ class EditorWindow(object):
 
         editmenu = tkinter.Menu(self.menubar, tearoff=0)
         editmenu.add_command(label="renum", command=self.renumber_listing)
+        editmenu.add_command(label="reformat", command=self.reformat_listing)
         editmenu.add_command(label="display tokens", command=self.debug_display_tokens)
         self.menubar.add_cascade(label="tools", menu=editmenu)
 
@@ -232,15 +169,15 @@ class EditorWindow(object):
         self.text.insert(tkinter.INSERT, converted_char) # Insert converted char
         return "break"
 
-#     def event_syntax_check(self, event):
-#         index = self.text.search(r'\s', "insert", backwards=True, regexp=True)
-#         if index == "":
-#             index ="1.0"
-#         else:
-#             index = self.text.index("%s+1c" % index)
-#         word = self.text.get(index, "insert")
-#         log.critical("inserted word: %r", word)
-#         print self.machine_api.parse_ascii_listing(word)
+    #     def event_syntax_check(self, event):
+    #         index = self.text.search(r'\s', "insert", backwards=True, regexp=True)
+    #         if index == "":
+    #             index ="1.0"
+    #         else:
+    #             index = self.text.index("%s+1c" % index)
+    #         word = self.text.get(index, "insert")
+    #         log.critical("inserted word: %r", word)
+    #         print self.machine_api.parse_ascii_listing(word)
 
     def setup_filepath(self, filepath):
         log.critical(filepath)
@@ -283,9 +220,8 @@ class EditorWindow(object):
 
     def debug_display_tokens(self):
         content = self.get_content()
-        program_dump = self.machine_api.ascii_listing2program_dump(content)
-        msg = pformat_program_dump(program_dump)
-        messagebox.showinfo("Program Dump:", msg, parent=self.root)
+        self.token_window = TokenWindow(self.cfg, self.root)
+        self.token_window.display_listing(content)
 
     def renumber_listing(self):
         # save text cursor and scroll position
@@ -299,6 +235,18 @@ class EditorWindow(object):
         # restore text cursor and scroll position
         self.text.restore_position()
 
+    def reformat_listing(self):
+        # save text cursor and scroll position
+        self.text.save_position()
+
+        # renumer the content
+        content = self.get_content()
+        content = self.machine_api.reformat_ascii_listing(content)
+        self.set_content(content)
+
+        # restore text cursor and scroll position
+        self.text.restore_position()
+
     def get_content(self):
         content = self.text.get("1.0", tkinter.END)
         content = content.strip()
@@ -350,6 +298,17 @@ def run_basic_editor(cfg, default_content=None):
 
 
 def test():
+    from dragonlib.utils.logging_utils import setup_logging
+
+    setup_logging(
+#        level=1 # hardcore debug ;)
+#         level=10  # DEBUG
+#         level=20  # INFO
+#         level=30  # WARNING
+#         level=40 # ERROR
+        level=50 # CRITICAL/FATAL
+    )
+
     CFG_DICT = {
         "verbosity": None,
         "display_cycle": False,
@@ -362,13 +321,12 @@ def test():
         "use_bus": False,
     }
     from dragonpy.Dragon32.config import Dragon32Cfg
+
     cfg = Dragon32Cfg(CFG_DICT)
 
-
-
     filepath = os.path.join(os.path.abspath(os.path.dirname(__file__)),
-        "..", "BASIC examples",
-        "hex_view01.bas"
+        # "..", "BASIC examples", "hex_view01.bas"
+        "..", "BASIC games", "INVADER.bas"
     )
 
     with open(filepath, "r") as f:
