@@ -54,6 +54,20 @@ class BasicTokenUtil(object):
         else:
             return result
 
+    def tokens2ascii(self, values):
+        line=""
+        old_value = None
+        for value in values:
+            if value == 0xff:
+                old_value = value
+                continue
+            if old_value is not None:
+                value = (old_value << 8) + value
+                old_value = None
+            code = self.token2ascii(value)
+            line += code
+        return line
+
     def chars2tokens(self, chars):
         return [ord(char) for char in chars]
 
@@ -105,12 +119,7 @@ class BasicTokenUtil(object):
                 tokens += self.chars2tokens(code_object.content)
         return tokens
 
-    def pformat_tokens(self, tokens):
-        """
-        format a tokenized BASIC program line. Useful for debugging.
-        returns a list of formated string lines.
-        """
-        result = []
+    def iter_token_values(self, tokens):
         token_value = None
         for token in tokens:
             if token == 0xff:
@@ -118,16 +127,23 @@ class BasicTokenUtil(object):
                 continue
 
             if token_value is not None:
-                token_value = (token_value << 8) + token
+                yield (token_value << 8) + token
+                token_value = None
             else:
-                token_value = token
+                yield token
 
+    def pformat_tokens(self, tokens):
+        """
+        format a tokenized BASIC program line. Useful for debugging.
+        returns a list of formated string lines.
+        """
+        result = []
+        for token_value in self.iter_token_values(tokens):
             char = self.token2ascii(token_value)
             if token_value > 0xff:
                 result.append("\t$%04x -> %s" % (token_value, repr(char)))
             else:
                 result.append("\t  $%02x -> %s" % (token_value, repr(char)))
-            token_value = None
 
         return result
 
@@ -190,25 +206,75 @@ class BasicLine(object):
         self.line_code = self.token_util.code_objects2token(code_objects)
 
     def get_tokens(self):
-        return [self.line_number] + self.line_code
+        """
+        return two bytes line number + the code
+        """
+        return list(word2bytes(self.line_number)) + self.line_code
+
+    def reformat(self):
+        # TODO: Use BASICParser to exclude string/comments etc.
+        space = self.token_util.ascii2token(" ")[0]
+
+        to_split=self.token_util.basic_token_dict.copy()
+        dont_split_tokens=self.token_util.ascii2token(":()+-*/^<=>")
+
+        for token_value in dont_split_tokens:
+            try:
+                del(to_split[token_value])
+            except KeyError: # e.g.: () are not tokens
+                pass
+
+        tokens=tuple(self.token_util.iter_token_values(self.line_code))
+
+        temp = []
+        was_token=False
+        for no, token in enumerate(tokens):
+            try:
+                next_token=tokens[no+1]
+            except IndexError:
+                next_token=None
+
+            if token in to_split:
+                print("X%sX" % to_split[token])
+
+                try:
+                    if temp[-1]!=space:
+                        temp.append(space)
+                except IndexError:
+                    pass
+                temp.append(token)
+
+                if not (next_token and next_token in dont_split_tokens):
+                    temp.append(space)
+                was_token=True
+            else:
+                if was_token and token==space:
+                    was_token=False
+                    continue
+                print("Y%rY" % self.token_util.tokens2ascii([token]))
+                temp.append(token)
+
+        temp = list_replace(temp, self.token_util.ascii2token("GO TO"), self.token_util.ascii2token("GOTO"))
+        temp = list_replace(temp, self.token_util.ascii2token("GO SUB"), self.token_util.ascii2token("GOSUB"))
+        temp = list_replace(temp, self.token_util.ascii2token(": "), self.token_util.ascii2token(":"))
+        temp = list_replace(temp, self.token_util.ascii2token("( "), self.token_util.ascii2token("("))
+        temp = list_replace(temp, self.token_util.ascii2token(", "), self.token_util.ascii2token(","))
+
+        self.line_code = temp
+
 
     def get_content(self, code=None):
         if code is None: # start
             code = self.line_code
 
         line = "%i " % self.line_number
-        old_value = None
-        for value in code:
-            if value == 0xff:
-                old_value = value
-                continue
-            if old_value is not None:
-                value = (old_value << 8) + value
-                old_value = None
-            code = self.token_util.token2ascii(value)
-            line += code
+        line += self.token_util.tokens2ascii(code)
+
         return line
 
+    def __repr__(self):
+        return "%r: %s" % (self.get_content(), " ".join(["$%02x" % t for t in self.line_code]))
+
     def log_line(self):
         log.critical("%r:\n\t%s",
             self.get_content(),
@@ -260,7 +326,7 @@ class BasicListing(object):
         count = len(basic_lines)
         for no, line in enumerate(basic_lines, 1):
             line.log_line()
-            line_tokens = [0x00] + line.get_tokens() + [0x00]
+            line_tokens = line.get_tokens() + [0x00]
 
             current_address += len(line_tokens) + 2
             program_dump += word2bytes(current_address)
@@ -369,6 +435,7 @@ class RenumTool(object):
             new_number *= 10
             line = self.line_no_regex.sub("%s\g<code>" % new_number, line)
             new_line = self.renum_regex.sub(self.renum_inline, line)
+            log.debug("%r -> %r", line, new_line)
             new_listing.append(new_line)
         return "\n".join(new_listing)
 
@@ -378,19 +445,16 @@ class RenumTool(object):
         """
         self.destinations = set()
         def collect_destinations(matchobj):
-            numbers = matchobj.group("on_goto_no")
+            numbers = matchobj.group("no")
             if numbers:
                 self.destinations.update(set(
                     [n.strip() for n in numbers.split(",")]
                 ))
-            number = matchobj.group("no")
-            if number:
-                self.destinations.add(number)
 
         for line in self._iter_lines(ascii_listing):
             self.renum_regex.sub(collect_destinations, line)
 
-        return sorted([int(no) for no in self.destinations])
+        return sorted([int(no) for no in self.destinations if no])
 
     def _iter_lines(self, ascii_listing):
         lines = ascii_listing.splitlines()
@@ -409,17 +473,9 @@ class RenumTool(object):
             new_number = old_number
         return new_number
 
-    def _replace_statement(self, matchobj):
-        old_number = matchobj.group("no")
-        new_number = self._get_new_line_number(matchobj.group(0), old_number)
-        return "".join([
-            matchobj.group("statement"),
-            matchobj.group("space"),
-            new_number
-        ])
-
-    def _replace_on_goto(self, matchobj):
-        old_numbers = matchobj.group("on_goto_no")
+    def renum_inline(self, matchobj):
+#         log.critical(matchobj.groups())
+        old_numbers = matchobj.group("no")
         if old_numbers[-1] == " ":
             # e.g.: space before comment: ON X GOTO 1,2 ' Comment
             space_after = " "
@@ -431,18 +487,11 @@ class RenumTool(object):
             for old_number in old_numbers
         ]
         return "".join([
-            matchobj.group("on_goto_statement"),
-            matchobj.group("on_goto_space"),
+            matchobj.group("statement"),
+            matchobj.group("space"),
             ",".join(new_numbers), space_after
         ])
 
-    def renum_inline(self, matchobj):
-#         log.critical(matchobj.groups())
-        if matchobj.group("on_goto_statement"):
-            return self._replace_on_goto(matchobj)
-        else:
-            return self._replace_statement(matchobj)
-
     def create_renum_dict(self, ascii_listing):
         old_numbers = [match[0] for match in self.line_no_regex.findall(ascii_listing)]
         renum_dict = {}
@@ -451,7 +500,8 @@ class RenumTool(object):
             renum_dict[old_number] = new_number
         return renum_dict
 
-if __name__ == "__main__":
+
+def _test_renum():
     from dragonlib.api import Dragon32API
 
     api = Dragon32API()
@@ -472,3 +522,44 @@ if __name__ == "__main__":
     print("-" * 79)
     print(api.renum_tool.get_destinations(listing))
     print("-" * 79)
+
+
+def _test_reformat():
+    import os
+    from dragonlib.utils.logging_utils import setup_logging
+
+    setup_logging(
+#        level=1 # hardcore debug ;)
+#         level=10  # DEBUG
+#         level=20  # INFO
+#         level=30  # WARNING
+#         level=40 # ERROR
+#         level=50 # CRITICAL/FATAL
+        level=99
+    )
+
+    from dragonlib.api import Dragon32API
+    api = Dragon32API()
+
+    # filepath = os.path.join(os.path.abspath(os.path.dirname(__file__)),
+    #     # "..", "BASIC examples", "hex_view01.bas"
+    #     "..", "..", "BASIC games", "INVADER.bas"
+    # )
+    #
+    # with open(filepath, "r") as f:
+    #     listing_ascii = f.read()
+
+    listing_ascii="""\
+10 ONPOINT(Y,K)GOTO250,250'ONPOINT(Y,K)GOTO250,250
+20 FORT=479TO 542:T(T)=0:Y(T)=28:NEXT
+30 I=I+1:PRINT"FORX=1TO 2:Y(Y)=0:NEXT"
+730 CLS:PRINT"FIXME: PLEASE WAIT [           ]";
+"""
+
+    print(
+        api.reformat_ascii_listing(listing_ascii)
+    )
+
+if __name__ == "__main__":
+    # _test_renum()
+    _test_reformat()
