@@ -286,10 +286,11 @@ class TestBASICParser(unittest.TestCase):
 #             print_parsed_lines=True
         )
 
+
 if __name__ == "__main__":
     from dragonlib.utils.logging_utils import setup_logging
 
-    setup_logging(log,
+    setup_logging(
 #         level=1 # hardcore debug ;)
 #         level=10  # DEBUG
 #         level=20  # INFO
