@@ -19,24 +19,27 @@ from __future__ import absolute_import, division, print_function
 
 import sys
 import os
-import queue
-
-try:
-    import tkinter
-except Exception as err:
-    print("Error importing Tkinter: %s" % err)
-    Tkinter = None
-
-
-from dragonpy.components.periphery import PeripheryBase, TkPeripheryBase
 import logging
 
-log=logging.getLogger(__name__)
+log = logging.getLogger(__name__)
+
+try:
+    # Python 3
+    import queue
+    import tkinter
+except ImportError:
+    # Python 2
+    import Queue as queue
+    import Tkinter as tkinter
 
 
-class Multicomp6809PeripheryBase(PeripheryBase):
-    def __init__(self, cfg):
-        super(Multicomp6809PeripheryBase, self).__init__(cfg)
+class Multicomp6809Periphery(object):
+    def __init__(self, cfg, cpu, memory, display_callback, user_input_queue):
+        self.cfg = cfg
+        self.cpu = cpu
+        self.memory = memory
+        self.display_callback = display_callback
+        self.user_input_queue = user_input_queue
 
 #     BUS_ADDR_AREAS = (
 #         (0xFFD8, 0xFFDF, "SD Card"),
@@ -46,7 +49,7 @@ class Multicomp6809PeripheryBase(PeripheryBase):
 #     )
         self.memory.add_read_byte_callback(self.read_acia_status, 0xffd0) #  Control/status port of ACIA
         self.memory.add_read_byte_callback(self.read_acia_data, 0xffd1) #  Data port of ACIA
-        
+
         self.memory.add_write_byte_callback(self.write_acia_status, 0xffd0) #  Control/status port of ACIA
         self.memory.add_write_byte_callback(self.write_acia_data, 0xffd1) #  Data port of ACIA
 
@@ -61,6 +64,10 @@ class Multicomp6809PeripheryBase(PeripheryBase):
         except queue.Empty:
             return 0x0
 
+        if isinstance(char, int):
+            log.critical("Ignore %s from user_input_queue", repr(char))
+            return 0x0
+
         value = ord(char)
         log.error("%04x| (%i) read from ACIA-data, send back %r $%x",
             op_address, cpu_cycles, char, value
@@ -69,72 +76,57 @@ class Multicomp6809PeripheryBase(PeripheryBase):
 
     def write_acia_data(self, cpu_cycles, op_address, address, value):
         char = chr(value)
-#         log.error("*"*79)
-#         log.error("Write to screen: %s ($%x)" , repr(char), value)
-#         log.error("*"*79)
+        log.debug("Write to screen: %s ($%x)" , repr(char), value)
 
-        if value >= 0x90: # FIXME: Why?
-            value -= 0x60
-            char = chr(value)
-#            log.error("convert value -= 0x30 to %s ($%x)" , repr(char), value)
+#         if value >= 0x90: # FIXME: Why?
+#             value -= 0x60
+#             char = chr(value)
+# #            log.error("convert value -= 0x30 to %s ($%x)" , repr(char), value)
+#
+#         if value <= 9: # FIXME: Why?
+#             value += 0x41
+#             char = chr(value)
+# #            log.error("convert value += 0x41 to %s ($%x)" , repr(char), value)
 
-        if value <= 9: # FIXME: Why?
-            value += 0x41
-            char = chr(value)
-#            log.error("convert value += 0x41 to %s ($%x)" , repr(char), value)
-
-        self.display_queue.put(char)
+        self.display_callback(char)
 
 
-
-
-class Multicomp6809PeripheryTk(TkPeripheryBase, Multicomp6809PeripheryBase):
-    TITLE = "DragonPy - Multicomp 6809"
-    GEOMETRY = "+500+300"
+"""
     KEYCODE_MAP = {
         127: 0x03, # Break Key
     }
-    INITAL_INPUT = "\r\n".join([
-#         'PRINT "HELLO WORLD!"',
-#         '? 123',
-
-        '10 FOR I=1 TO 3',
-        '20 PRINT STR$(I)+" DRAGONPY"',
-        '30 NEXT I',
-        'RUN',
-        '',
-        'LIST',
-    ]) + "\r\n"
-
-    def event_return(self, event):
-        self.user_input_queue.put("\r")
-#         self.user_input_queue.put("\n")
+"""
 
 
-# Multicomp6809Periphery = Multicomp6809PeripherySerial
-Multicomp6809Periphery = Multicomp6809PeripheryTk
+#------------------------------------------------------------------------------
 
 
 def test_run():
+    import os
+    import sys
     import subprocess
     cmd_args = [
         sys.executable,
-#         "/usr/bin/pypy",
         os.path.join("..", "DragonPy_CLI.py"),
-#         "--verbosity=5",
-#         "--verbosity=10", # DEBUG
-#         "--verbosity=20", # INFO
-#         "--verbosity=30", # WARNING
-#         "--verbosity=40", # ERROR
-        "--verbosity=50", # CRITICAL/FATAL
+#         "-h"
+#         "--log_list",
+        "--log", "dragonpy.Multicomp6809,10", # "dragonpy.Dragon32.MC6821_PIA,10",
 
-#                       "--max=1660000",
-#         "--max=1000",
-
-        "--machine=Multicomp6809",
+#          "--verbosity", "10", # DEBUG
+#         "--verbosity", "20", # INFO
+#         "--verbosity", "30", # WARNING
+#         "--verbosity", "40", # ERROR
+#         "--verbosity", "50", # CRITICAL/FATAL
+        "--verbosity", "99", # nearly all off
+#         "--machine", "Dragon32", "run",
+        "--machine", "Multicomp6809", "run",
+#        "--max_ops", "1",
+#        "--trace",
     ]
     print("Startup CLI with: %s" % " ".join(cmd_args[1:]))
     subprocess.Popen(cmd_args, cwd="..").wait()
 
+
 if __name__ == "__main__":
     test_run()
+
