@@ -16,13 +16,15 @@ from __future__ import absolute_import, division, print_function
 
 from decimal import Decimal
 import binascii
+import logging
 import sys
 import unittest
 
-from dragonlib.utils import lib2and3
-from dragonlib.utils.logging_utils import log, setup_logging
+from dragonlib.utils import six
 from dragonpy.tests.test_base import TextTestRunner2, BaseStackTestCase
 
+log = logging.getLogger(__name__)
+
 
 class Test6809_Program(BaseStackTestCase):
 #     def setUp(self):
@@ -142,7 +144,7 @@ class Test6809_Program(BaseStackTestCase):
         return crc32 ^ 0xFFFFFFFF
 
     def _test_crc32(self, txt):
-        if lib2and3.PY3:
+        if six.PY3:
             txt = bytes(txt, encoding="UTF-8")
         crc32 = self._crc32(txt)
         excpected_crc32 = binascii.crc32(txt) & 0xffffffff
