@@ -14,17 +14,12 @@
 
 from __future__ import absolute_import, division, print_function
 
-
 import logging
 import sys
 import unittest
 
 from dragonpy.tests.test_base import TextTestRunner2, Test6809_BASIC_simple6809_Base
-
-
 from dragonpy.utils.BASIC09_floating_point import BASIC09FloatingPoint
-from dragonlib.utils.logging_utils import setup_logging
-
 
 
 log = logging.getLogger("DragonPy")
@@ -34,7 +29,7 @@ class Test_simple6809_BASIC(Test6809_BASIC_simple6809_Base):
     def test_print01(self):
         self.periphery.add_to_input_queue('? "FOO"\r\n')
         op_call_count, cycles, output = self._run_until_OK()
-#         print op_call_count, cycles, output
+#         print(op_call_count, cycles, output)
         self.assertEqual(output,
             ['? "FOO"\r\n', 'FOO\r\n', 'OK\r\n']
         )
@@ -44,7 +39,7 @@ class Test_simple6809_BASIC(Test6809_BASIC_simple6809_Base):
     def test_print02(self):
         self.periphery.add_to_input_queue('PRINT "BAR"\r\n')
         op_call_count, cycles, output = self._run_until_OK()
-#         print op_call_count, cycles, output
+#         print(op_call_count, cycles, output)
         self.assertEqual(output,
             ['PRINT "BAR"\r\n', 'BAR\r\n', 'OK\r\n']
         )
@@ -53,7 +48,7 @@ class Test_simple6809_BASIC(Test6809_BASIC_simple6809_Base):
     def test_print03(self):
         self.periphery.add_to_input_queue('PRINT 0\r\n')
         op_call_count, cycles, output = self._run_until_OK()
-#         print op_call_count, cycles, output
+#         print(op_call_count, cycles, output)
         self.assertEqual(output,
             ['PRINT 0\r\n', ' 0 \r\n', 'OK\r\n']
         )
@@ -62,7 +57,7 @@ class Test_simple6809_BASIC(Test6809_BASIC_simple6809_Base):
     def test_print04(self):
         self.periphery.add_to_input_queue('PRINT 4\r\n')
         op_call_count, cycles, output = self._run_until_OK()
-#         print op_call_count, cycles, output
+#         print(op_call_count, cycles, output)
         self.assertEqual(output,
             ['PRINT 4\r\n', ' 4 \r\n', 'OK\r\n']
         )
@@ -74,9 +69,9 @@ class Test_simple6809_BASIC(Test6809_BASIC_simple6809_Base):
             '? "A="+STR$(A)\r\n'
         )
         op_call_count, cycles, output = self._run_until_OK(
-            OK_count=2, max_ops=12000
+            OK_count=2, max_ops=20000
         )
-#         print op_call_count, cycles, output
+        print(op_call_count, cycles, output)
         self.assertEqual(output,
             ['A=0\r\n', 'OK\r\n', '? "A="+STR$(A)\r\n', 'A= 0\r\n', 'OK\r\n']
         )
@@ -90,7 +85,7 @@ class Test_simple6809_BASIC(Test6809_BASIC_simple6809_Base):
         op_call_count, cycles, output = self._run_until_OK(
             OK_count=2, max_ops=8500
         )
-#         print op_call_count, cycles, output
+#         print(op_call_count, cycles, output)
         self.assertEqual(output,
             ['A$="B"\r\n', 'OK\r\n', '?A$\r\n', 'B\r\n', 'OK\r\n']
         )
@@ -98,7 +93,7 @@ class Test_simple6809_BASIC(Test6809_BASIC_simple6809_Base):
     def test_TM_Error(self):
         self.periphery.add_to_input_queue('X="Y"\r\n')
         op_call_count, cycles, output = self._run_until_OK(max_ops=3500)
-#         print op_call_count, cycles, output
+#         print(op_call_count, cycles, output)
         self.assertEqual(output,
             ['X="Y"\r\n', '?TM ERROR\r\n', 'OK\r\n']
         )
@@ -108,7 +103,7 @@ class Test_simple6809_BASIC_Float1(Test6809_BASIC_simple6809_Base):
     def test_print_float(self):
         self.periphery.add_to_input_queue('?2.5\r\n')
         op_call_count, cycles, output = self._run_until_OK(max_ops=5500)
-#         print op_call_count, cycles, output
+#         print(op_call_count, cycles, output)
         self.assertEqual(output,
             ['?2.5\r\n', ' 2.5 \r\n', 'OK\r\n']
         )
@@ -116,7 +111,7 @@ class Test_simple6809_BASIC_Float1(Test6809_BASIC_simple6809_Base):
     def test_print_negative_float(self):
         self.periphery.add_to_input_queue('?-3.4\r\n')
         op_call_count, cycles, output = self._run_until_OK(max_ops=6300)
-#         print op_call_count, cycles, output
+#         print(op_call_count, cycles, output)
         self.assertEqual(output,
             ['?-3.4\r\n', '-3.4 \r\n', 'OK\r\n']
         )
@@ -124,7 +119,7 @@ class Test_simple6809_BASIC_Float1(Test6809_BASIC_simple6809_Base):
     def test_print_rounded_float(self):
         self.periphery.add_to_input_queue('?1.123456789\r\n')
         op_call_count, cycles, output = self._run_until_OK(max_ops=15000)
-#         print op_call_count, cycles, output
+#         print(op_call_count, cycles, output)
         self.assertEqual(output,
             ['?1.123456789\r\n', ' 1.12345679 \r\n', 'OK\r\n']
         )
@@ -132,7 +127,7 @@ class Test_simple6809_BASIC_Float1(Test6809_BASIC_simple6809_Base):
     def test_division1(self):
         self.periphery.add_to_input_queue('?6/2\r\n')
         op_call_count, cycles, output = self._run_until_OK(max_ops=4500)
-#         print op_call_count, cycles, output
+#         print(op_call_count, cycles, output)
         self.assertEqual(output,
             ['?6/2\r\n', ' 3 \r\n', 'OK\r\n']
         )
@@ -140,7 +135,7 @@ class Test_simple6809_BASIC_Float1(Test6809_BASIC_simple6809_Base):
     def test_division2(self):
         self.periphery.add_to_input_queue('?3/2\r\n')
         op_call_count, cycles, output = self._run_until_OK(max_ops=4500)
-#         print op_call_count, cycles, output
+#         print(op_call_count, cycles, output)
         self.assertEqual(output,
             ['?3/2\r\n', ' 1.5 \r\n', 'OK\r\n']
         )
@@ -148,7 +143,7 @@ class Test_simple6809_BASIC_Float1(Test6809_BASIC_simple6809_Base):
     def test_division3(self):
         self.periphery.add_to_input_queue('?5/3\r\n')
         op_call_count, cycles, output = self._run_until_OK(max_ops=5100)
-#         print op_call_count, cycles, output
+#         print(op_call_count, cycles, output)
         self.assertEqual(output,
             ['?5/3\r\n', ' 1.66666667 \r\n', 'OK\r\n']
         )
@@ -156,7 +151,7 @@ class Test_simple6809_BASIC_Float1(Test6809_BASIC_simple6809_Base):
     def test_multiply1(self):
         self.periphery.add_to_input_queue('?3*2\r\n')
         op_call_count, cycles, output = self._run_until_OK(max_ops=4500)
-#         print op_call_count, cycles, output
+#         print(op_call_count, cycles, output)
         self.assertEqual(output,
             ['?3*2\r\n', ' 6 \r\n', 'OK\r\n']
         )
@@ -164,7 +159,7 @@ class Test_simple6809_BASIC_Float1(Test6809_BASIC_simple6809_Base):
     def test_multiply2(self):
         self.periphery.add_to_input_queue('?8*-3\r\n')
         op_call_count, cycles, output = self._run_until_OK(max_ops=5100)
-#         print op_call_count, cycles, output
+#         print(op_call_count, cycles, output)
         self.assertEqual(output,
             ['?8*-3\r\n', '-24 \r\n', 'OK\r\n']
         )
@@ -173,7 +168,7 @@ class Test_simple6809_BASIC_NumericFunctions(Test6809_BASIC_simple6809_Base):
     def test_ABS(self):
         self.periphery.add_to_input_queue('?ABS(-2)\r\n')
         op_call_count, cycles, output = self._run_until_OK(max_ops=7900)
-#         print op_call_count, cycles, output
+#         print(op_call_count, cycles, output)
         self.assertEqual(output,
             ['?ABS(-2)\r\n', ' 2 \r\n', 'OK\r\n']
         )
@@ -181,7 +176,7 @@ class Test_simple6809_BASIC_NumericFunctions(Test6809_BASIC_simple6809_Base):
     def test_ATN(self):
         self.periphery.add_to_input_queue('?ATN(2)\r\n')
         op_call_count, cycles, output = self._run_until_OK(max_ops=17200)
-#         print op_call_count, cycles, output
+#         print(op_call_count, cycles, output)
         self.assertEqual(output,
             ['?ATN(2)\r\n', ' 1.10714872 \r\n', 'OK\r\n']
         )
@@ -189,7 +184,7 @@ class Test_simple6809_BASIC_NumericFunctions(Test6809_BASIC_simple6809_Base):
     def test_COS(self):
         self.periphery.add_to_input_queue('?COS(3)\r\n')
         op_call_count, cycles, output = self._run_until_OK(max_ops=15000)
-#         print op_call_count, cycles, output
+#         print(op_call_count, cycles, output)
         self.assertEqual(output,
             ['?COS(3)\r\n', '-.989992497 \r\n', 'OK\r\n']
         )
@@ -197,7 +192,7 @@ class Test_simple6809_BASIC_NumericFunctions(Test6809_BASIC_simple6809_Base):
     def test_EXP(self):
         self.periphery.add_to_input_queue('?EXP(10)\r\n')
         op_call_count, cycles, output = self._run_until_OK(max_ops=14000)
-#         print op_call_count, cycles, output
+#         print(op_call_count, cycles, output)
         self.assertEqual(output,
             ['?EXP(10)\r\n', ' 22026.4658 \r\n', 'OK\r\n']
         )
@@ -205,7 +200,7 @@ class Test_simple6809_BASIC_NumericFunctions(Test6809_BASIC_simple6809_Base):
     def test_FIX(self):
         self.periphery.add_to_input_queue('?FIX(-7.4)\r\n')
         op_call_count, cycles, output = self._run_until_OK(max_ops=11000)
-#         print op_call_count, cycles, output
+#         print(op_call_count, cycles, output)
         self.assertEqual(output,
             ['?FIX(-7.4)\r\n', '-7 \r\n', 'OK\r\n']
         )
@@ -213,7 +208,7 @@ class Test_simple6809_BASIC_NumericFunctions(Test6809_BASIC_simple6809_Base):
     def test_INT(self):
         self.periphery.add_to_input_queue('?INT(-7.4)\r\n')
         op_call_count, cycles, output = self._run_until_OK(max_ops=11000)
-#         print op_call_count, cycles, output
+#         print(op_call_count, cycles, output)
         self.assertEqual(output,
             ['?INT(-7.4)\r\n', '-8 \r\n', 'OK\r\n']
         )
@@ -221,7 +216,7 @@ class Test_simple6809_BASIC_NumericFunctions(Test6809_BASIC_simple6809_Base):
     def test_LOG(self):
         self.periphery.add_to_input_queue('?LOG(2)\r\n')
         op_call_count, cycles, output = self._run_until_OK(max_ops=13000)
-#         print op_call_count, cycles, output
+#         print(op_call_count, cycles, output)
         self.assertEqual(output,
             ['?LOG(2)\r\n', ' .693147181 \r\n', 'OK\r\n']
         )
@@ -232,7 +227,7 @@ class Test_simple6809_BASIC_NumericFunctions(Test6809_BASIC_simple6809_Base):
         self.cpu.memory.write_byte(addr, value)
         self.periphery.add_to_input_queue('?PEEK(%s)\r\n' % addr)
         op_call_count, cycles, output = self._run_until_OK(max_ops=9000)
-#         print op_call_count, cycles, output
+#         print(op_call_count, cycles, output)
         self.assertEqual(output, [
             '?PEEK(%i)\r\n' % addr,
             ' %i \r\n' % value,
@@ -245,7 +240,7 @@ class Test_simple6809_BASIC_NumericFunctions(Test6809_BASIC_simple6809_Base):
         self.cpu.memory.write_byte(addr, 0xff)
         self.periphery.add_to_input_queue('POKE%i,%i\r\n' % (addr, value))
         op_call_count, cycles, output = self._run_until_OK(max_ops=4600)
-#         print op_call_count, cycles, output
+#         print(op_call_count, cycles, output)
         self.assertEqual(output, [
             'POKE%i,%i\r\n' % (addr, value),
             'OK\r\n'
@@ -255,7 +250,7 @@ class Test_simple6809_BASIC_NumericFunctions(Test6809_BASIC_simple6809_Base):
     def test_RND(self): # FIXME: How to test is better?
         self.periphery.add_to_input_queue('?RND(1)\r\n') # will always return 1
         op_call_count, cycles, output = self._run_until_OK(max_ops=9000)
-#         print op_call_count, cycles, output
+#         print(op_call_count, cycles, output)
         self.assertEqual(output,
             ['?RND(1)\r\n', ' 1 \r\n', 'OK\r\n']
         )
@@ -263,7 +258,7 @@ class Test_simple6809_BASIC_NumericFunctions(Test6809_BASIC_simple6809_Base):
     def test_SGN(self):
         self.periphery.add_to_input_queue('?SGN(10):?SGN(0):?SGN(-3)\r\n')
         op_call_count, cycles, output = self._run_until_OK(max_ops=21000)
-#         print op_call_count, cycles, output
+#         print(op_call_count, cycles, output)
         self.assertEqual(output, [
             '?SGN(10):?SGN(0):?SGN(-3)\r\n',
             ' 1 \r\n', ' 0 \r\n', '-1 \r\n',
@@ -273,7 +268,7 @@ class Test_simple6809_BASIC_NumericFunctions(Test6809_BASIC_simple6809_Base):
     def test_SIN(self):
         self.periphery.add_to_input_queue('?SIN(12)\r\n')
         op_call_count, cycles, output = self._run_until_OK(max_ops=15000)
-#         print op_call_count, cycles, output
+#         print(op_call_count, cycles, output)
         self.assertEqual(output,
             ['?SIN(12)\r\n', '-.536572917 \r\n', 'OK\r\n']
         )
@@ -281,7 +276,7 @@ class Test_simple6809_BASIC_NumericFunctions(Test6809_BASIC_simple6809_Base):
     def test_SQR(self):
         self.periphery.add_to_input_queue('?SQR(2)\r\n')
         op_call_count, cycles, output = self._run_until_OK(max_ops=20000)
-#         print op_call_count, cycles, output
+#         print(op_call_count, cycles, output)
         self.assertEqual(output,
             ['?SQR(2)\r\n', ' 1.41421356 \r\n', 'OK\r\n']
         )
@@ -289,7 +284,7 @@ class Test_simple6809_BASIC_NumericFunctions(Test6809_BASIC_simple6809_Base):
     def test_TAN(self):
         self.periphery.add_to_input_queue('?TAN(5)\r\n')
         op_call_count, cycles, output = self._run_until_OK(max_ops=20400)
-#         print op_call_count, cycles, output
+#         print(op_call_count, cycles, output)
         self.assertEqual(output,
             ['?TAN(5)\r\n', '-3.38051501 \r\n', 'OK\r\n']
         )
@@ -297,7 +292,7 @@ class Test_simple6809_BASIC_NumericFunctions(Test6809_BASIC_simple6809_Base):
     def test_CHR(self):
         self.periphery.add_to_input_queue('?CHR$(64)\r\n')
         op_call_count, cycles, output = self._run_until_OK(max_ops=6000)
-#         print op_call_count, cycles, output
+#         print(op_call_count, cycles, output)
         self.assertEqual(output,
             ['?CHR$(64)\r\n', '@\r\n', 'OK\r\n']
         )
@@ -305,7 +300,7 @@ class Test_simple6809_BASIC_NumericFunctions(Test6809_BASIC_simple6809_Base):
     def test_HEX(self):
         self.periphery.add_to_input_queue('?HEX$(30)\r\n')
         op_call_count, cycles, output = self._run_until_OK(max_ops=6100)
-#         print op_call_count, cycles, output
+#         print(op_call_count, cycles, output)
         self.assertEqual(output,
             ['?HEX$(30)\r\n', '1E\r\n', 'OK\r\n']
         )
@@ -313,7 +308,7 @@ class Test_simple6809_BASIC_NumericFunctions(Test6809_BASIC_simple6809_Base):
     def test_STR(self):
         self.periphery.add_to_input_queue('?STR$(12.34)\r\n')
         op_call_count, cycles, output = self._run_until_OK(max_ops=12000)
-#         print op_call_count, cycles, output
+#         print(op_call_count, cycles, output)
         self.assertEqual(output,
             ['?STR$(12.34)\r\n', ' 12.34\r\n', 'OK\r\n']
         )
@@ -321,7 +316,7 @@ class Test_simple6809_BASIC_NumericFunctions(Test6809_BASIC_simple6809_Base):
     def test_LEFT(self):
         self.periphery.add_to_input_queue('?LEFT$("ABCD",2)\r\n')
         op_call_count, cycles, output = self._run_until_OK(max_ops=8000)
-#         print op_call_count, cycles, output
+#         print(op_call_count, cycles, output)
         self.assertEqual(output,
             ['?LEFT$("ABCD",2)\r\n', 'AB\r\n', 'OK\r\n']
         )
@@ -329,7 +324,7 @@ class Test_simple6809_BASIC_NumericFunctions(Test6809_BASIC_simple6809_Base):
     def test_MID(self):
         self.periphery.add_to_input_queue('?MID$("ABCDE",2,3)\r\n')
         op_call_count, cycles, output = self._run_until_OK(max_ops=10000)
-#         print op_call_count, cycles, output
+#         print(op_call_count, cycles, output)
         self.assertEqual(output,
             ['?MID$("ABCDE",2,3)\r\n', 'BCD\r\n', 'OK\r\n']
         )
@@ -337,7 +332,7 @@ class Test_simple6809_BASIC_NumericFunctions(Test6809_BASIC_simple6809_Base):
     def test_RIGHT(self):
         self.periphery.add_to_input_queue('?RIGHT$("ABCD",2)\r\n')
         op_call_count, cycles, output = self._run_until_OK(max_ops=8000)
-#         print op_call_count, cycles, output
+#         print(op_call_count, cycles, output)
         self.assertEqual(output,
             ['?RIGHT$("ABCD",2)\r\n', 'CD\r\n', 'OK\r\n']
         )
@@ -345,7 +340,7 @@ class Test_simple6809_BASIC_NumericFunctions(Test6809_BASIC_simple6809_Base):
     def test_STRING(self):
         self.periphery.add_to_input_queue('?STRING$(4,"*")\r\n')
         op_call_count, cycles, output = self._run_until_OK(max_ops=8000)
-#         print op_call_count, cycles, output
+#         print(op_call_count, cycles, output)
         self.assertEqual(output,
             ['?STRING$(4,"*")\r\n', '****\r\n', 'OK\r\n']
         )
@@ -353,7 +348,7 @@ class Test_simple6809_BASIC_NumericFunctions(Test6809_BASIC_simple6809_Base):
     def test_ASC(self):
         self.periphery.add_to_input_queue('X$="@":?ASC(X$)\r\n')
         op_call_count, cycles, output = self._run_until_OK(max_ops=15000)
-#         print op_call_count, cycles, output
+#         print(op_call_count, cycles, output)
         self.assertEqual(output,
             ['X$="@":?ASC(X$)\r\n', ' 64 \r\n', 'OK\r\n']
         )
@@ -361,7 +356,7 @@ class Test_simple6809_BASIC_NumericFunctions(Test6809_BASIC_simple6809_Base):
     def test_INSTR(self):
         self.periphery.add_to_input_queue('?INSTR(2,"ABCDABCD","A")\r\n')
         op_call_count, cycles, output = self._run_until_OK(max_ops=13000)
-#         print op_call_count, cycles, output
+#         print(op_call_count, cycles, output)
         self.assertEqual(output,
             ['?INSTR(2,"ABCDABCD","A")\r\n', ' 5 \r\n', 'OK\r\n']
         )
@@ -369,7 +364,7 @@ class Test_simple6809_BASIC_NumericFunctions(Test6809_BASIC_simple6809_Base):
     def test_LEN(self):
         self.periphery.add_to_input_queue('?LEN("FOO")\r\n')
         op_call_count, cycles, output = self._run_until_OK(max_ops=7500)
-#         print op_call_count, cycles, output
+#         print(op_call_count, cycles, output)
         self.assertEqual(output,
             ['?LEN("FOO")\r\n', ' 3 \r\n', 'OK\r\n']
         )
@@ -377,7 +372,7 @@ class Test_simple6809_BASIC_NumericFunctions(Test6809_BASIC_simple6809_Base):
     def test_VAL(self):
         self.periphery.add_to_input_queue('?VAL("12")\r\n')
         op_call_count, cycles, output = self._run_until_OK(max_ops=8000)
-#         print op_call_count, cycles, output
+#         print(op_call_count, cycles, output)
         self.assertEqual(output,
             ['?VAL("12")\r\n', ' 12 \r\n', 'OK\r\n']
         )
@@ -403,7 +398,7 @@ class Test_simple6809_BASIC_Float2(Test6809_BASIC_simple6809_Base):
         self.assertFPA(value, 0x005c, 0x0061)
 
     def test_transfer_fpa0_to_fpa1(self):
-        self.cpu.memory.ram.load(0x004f, data=[
+        self.cpu.memory.load(0x004f, data=[
             0x12, # FPA 0 - exponent
             0x34, # FPA 0 - MS
             0x56, # FPA 0 - NMS
@@ -417,8 +412,8 @@ class Test_simple6809_BASIC_Float2(Test6809_BASIC_simple6809_Base):
 #        self.cpu.memory.ram.print_dump(0x004f, 0x0054)  # FPA0 # FPA0
 #        self.cpu.memory.ram.print_dump(0x005c, 0x0061) # FPA1
         self.assertEqual(
-            self.cpu.memory.ram._mem[0x004f:0x0055],
-            self.cpu.memory.ram._mem[0x005c:0x0062],
+            self.cpu.memory.get(start=0x004f, end=0x0055),
+            self.cpu.memory.get(start=0x005c, end=0x0062)
         )
 
     def test_ACCD_to_FPA0(self):
@@ -445,7 +440,7 @@ class Test_simple6809_BASIC_Float2(Test6809_BASIC_simple6809_Base):
             ])
 #            self.cpu.memory.ram.print_dump(0x004f, 0x0054)  # FPA0
 
-            ram = self.cpu.memory.ram._mem[0x004f:0x0055]
+            ram = self.cpu.memory.get(start=0x004f, end=0x0055)
 
             fp = BASIC09FloatingPoint(test_value)
 #            fp.print_values()
@@ -487,7 +482,7 @@ class Test_simple6809_BASIC_Float2(Test6809_BASIC_simple6809_Base):
 
             # Set FPA0 via python float implementation
             fp = BASIC09FloatingPoint(test_value)
-            self.cpu.memory.ram.load(0x004f, fp.get_bytes())
+            self.cpu.memory.load(0x004f, fp.get_bytes())
 
             self.cpu_test_run(start=0x0000, end=None, mem=[
                 0xBD, 0xe6, 0x82, #             JSR   $e682 - CONVERT FPA0 TO A TWO BYTE INTEGER to D
@@ -546,7 +541,7 @@ class Test_simple6809_BASIC_Float2(Test6809_BASIC_simple6809_Base):
             ])
 #            self.cpu.memory.ram.print_dump(0x004f, 0x0054)  # FPA0
 
-            ram = self.cpu.memory.ram._mem[0x004f:0x0055]
+            ram = self.cpu.memory.get(start=0x004f, end=0x0055)
 
             fp = BASIC09FloatingPoint(test_value)
 #            fp.print_values()
@@ -590,7 +585,9 @@ WIP:
         ])
         self.assertFPA0(dividend) # Test if value is in FPA0
 
-        setup_logging(log, level=20)
+        from dragonlib.utils.logging_utils import setup_logging
+
+    setup_logging(log, level=20)
         self.cpu_test_run(start=0x0300, end=None, mem=[
             0xBD, 0xed, 0xcb, # JSR   $edcb  ; DIVIDE FPA0 BY 10
         ])
@@ -623,7 +620,9 @@ WIP:
 #        ])
 #        self.assertFPA1(dividend) # Test if value is in FPA1
 
-        setup_logging(log, level=20)
+        from dragonlib.utils.logging_utils import setup_logging
+
+    setup_logging(log, level=20)
 #        self.cpu.index_x.set(divisor)
         self.cpu.accu_d.set(divisor)
         self.cpu_test_run(start=0x0300, end=None, mem=[
@@ -636,7 +635,9 @@ WIP:
 #        ])
 #        self.assertFPA0(divisor) # Test if value is in FPA0
 #
-#        setup_logging(log, level=20)
+#        from dragonlib.utils.logging_utils import setup_logging
+
+    setup_logging(log, level=20)
 ##        self.cpu_test_run2(start=0x0306, count=100, mem=[
 #        self.cpu_test_run(start=0x0300, end=None, mem=[
 #            0xBD, 0xed, 0xdc, # 0306  JSR   $edda  ; divide FPA1 by FPA0
@@ -652,8 +653,10 @@ WIP:
 
 
 if __name__ == '__main__':
+    from dragonlib.utils.logging_utils import setup_logging
+
     setup_logging(log,
-#        level=1 # hardcore debug ;)
+#         level=1 # hardcore debug ;)
 #        level=10 # DEBUG
 #        level=20 # INFO
 #        level=30 # WARNING
