@@ -15,14 +15,14 @@ from __future__ import absolute_import, division, print_function
 
 import unittest
 
-from dragonlib.utils.logging_utils import setup_logging, log
+from dragonlib.utils.logging_utils import setup_logging
 from dragonpy.tests.test_base import TextTestRunner2
 
 
 if __name__ == '__main__':
     from dragonlib.utils.logging_utils import setup_logging
 
-    setup_logging(log,
+    setup_logging(
 #         level=1 # hardcore debug ;)
 #         level=10 # DEBUG
 #         level=20 # INFO
